
TODO: TODO_70_48_96_29: be able to assert remaining `arg_value`-s

Do it via some kind of test builder where we can list them optionally (if not specified, not asserted).

See also TODO: TODO_32_99_70_35: JSONPath to verify response data.

